/* Driver template for the LEMON parser generator.
** The author disclaims copyright to this source code.
*/
/* First off, code is included that follows the "include" declaration
** in the input grammar file. */
#include <stdio.h>
#line 12 "sqlextract/parser.ly"

#include <assert.h>
#include <stdlib.h>
#include <string.h>
#include <sqlextract/filter/arbval.h>
#include <sqlextract/filter/filter.h>
#include <sqlextract/tables/table.h>
#include <sqlextract/tables/tablespace.h>
#include <time.h> /* for KW_CTIME */
#include <sqlextract/strtools.h>

#include <sqlextract/command.h>
#include <sqlextract/commands/command_select.h>

#if INTERFACE
#define TK_EOF 0
#include <sqlextract/filter/filter.h>
#include <sqlextract/strid.h>
#include <sqlextract/error.h>
#include <sqlextract/util.h>

struct logfilterParserParams {
	struct strid_t *si;
	struct command_t *command;
	struct tablespace_t *tablespace;
	struct table_t *table_singlerow;
	logfilter_error error;
};
#endif
#line 38 "sqlextract/parser.c"
#include "sqlextract/parser.h"
/* Next is all token values, in a form suitable for use by makeheaders.
** This section will be null unless lemon is run with the -m switch.
*/
/* 
** These constants (all generated automatically by the parser generator)
** specify the various kinds of tokens (terminals) that the parser
** understands. 
**
** Each symbol here is a terminal symbol in the grammar.
*/
#if INTERFACE
#define TK_ID                              1
#define TK_ABORT                           2
#define TK_ACTION                          3
#define TK_AFTER                           4
#define TK_ANALYZE                         5
#define TK_ASC                             6
#define TK_ATTACH                          7
#define TK_BEFORE                          8
#define TK_BEGIN                           9
#define TK_BY                             10
#define TK_CASCADE                        11
#define TK_CAST                           12
#define TK_COLUMNKW                       13
#define TK_CONFLICT                       14
#define TK_DATABASE                       15
#define TK_DEFERRED                       16
#define TK_DESC                           17
#define TK_DETACH                         18
#define TK_EACH                           19
#define TK_END                            20
#define TK_EXCLUSIVE                      21
#define TK_EXPLAIN                        22
#define TK_FAIL                           23
#define TK_FOR                            24
#define TK_IGNORE                         25
#define TK_IMMEDIATE                      26
#define TK_INITIALLY                      27
#define TK_INSTEAD                        28
#define TK_LIKE_KW                        29
#define TK_MATCH                          30
#define TK_NO                             31
#define TK_PLAN                           32
#define TK_QUERY                          33
#define TK_KEY                            34
#define TK_OF                             35
#define TK_OFFSET                         36
#define TK_PRAGMA                         37
#define TK_RAISE                          38
#define TK_RECURSIVE                      39
#define TK_REGEXP                         40
#define TK_RELEASE                        41
#define TK_REPLACE                        42
#define TK_RESTRICT                       43
#define TK_ROW                            44
#define TK_ROLLBACK                       45
#define TK_SAVEPOINT                      46
#define TK_TEMP                           47
#define TK_TRIGGER                        48
#define TK_VACUUM                         49
#define TK_VIEW                           50
#define TK_VIRTUAL                        51
#define TK_WITH                           52
#define TK_WITHOUT                        53
#define TK_REINDEX                        54
#define TK_RENAME                         55
#define TK_CTIME_KW                       56
#define TK_IF                             57
#define TK_ANY                            58
#define TK_OR                             59
#define TK_AND                            60
#define TK_NOT                            61
#define TK_IS                             62
#define TK_BETWEEN                        63
#define TK_IN                             64
#define TK_ISNULL                         65
#define TK_NOTNULL                        66
#define TK_NE                             67
#define TK_EQ                             68
#define TK_GT                             69
#define TK_LE                             70
#define TK_LT                             71
#define TK_GE                             72
#define TK_ESCAPE                         73
#define TK_BITAND                         74
#define TK_BITOR                          75
#define TK_LSHIFT                         76
#define TK_RSHIFT                         77
#define TK_PLUS                           78
#define TK_MINUS                          79
#define TK_STAR                           80
#define TK_SLASH                          81
#define TK_REM                            82
#define TK_CONCAT                         83
#define TK_COLLATE                        84
#define TK_BITNOT                         85
#define TK_STRING                         86
#define TK_INDEXED                        87
#define TK_SELECT                         88
#define TK_COMMA                          89
#define TK_FROM                           90
#define TK_LIMIT                          91
#define TK_WHERE                          92
#define TK_LP                             93
#define TK_RP                             94
#define TK_NULL                           95
#define TK_INTEGER                        96
#define TK_FLOAT                          97
#define TK_BLOB                           98
#define TK_VARIABLE                       99
#define TK_BINARY                         100
#endif
/* Make sure the INTERFACE macro is defined.
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/* The next thing included is series of defines which control
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 terminals
**                       and nonterminals.  "int" is used otherwise.
**    YYNOCODE           is a number of type YYCODETYPE which corresponds
**                       to no legal terminal or nonterminal number.  This
**                       number is used to fill in empty slots of the hash 
**                       table.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       have fall-back values which should be used if the
**                       original value of the token will not parse.
**    YYACTIONTYPE       is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 rules and
**                       states combined.  "int" is used otherwise.
**    logfilterParserTOKENTYPE     is the data type used for minor tokens given 
**                       directly to the parser from the tokenizer.
**    YYMINORTYPE        is the data type used for all minor tokens.
**                       This is typically a union of many types, one of
**                       which is logfilterParserTOKENTYPE.  The entry in the union
**                       for base tokens is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    logfilterParserARG_SDECL     A static variable declaration for the %extra_argument
**    logfilterParserARG_PDECL     A parameter declaration for the %extra_argument
**    logfilterParserARG_STORE     Code to store %extra_argument into yypParser
**    logfilterParserARG_FETCH     Code to extract %extra_argument from yypParser
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
*/
#define YYCODETYPE unsigned char
#define YYNOCODE 131
#define YYACTIONTYPE unsigned char
#define YYWILDCARD 58
#if INTERFACE
#define logfilterParserTOKENTYPE  char * 
#endif
typedef union {
  int yyinit;
  logfilterParserTOKENTYPE yy0;
  struct command_t * yy2;
  char * yy33;
  struct filter_t * yy61;
  struct arbval_t * yy67;
  int yy72;
  struct selcollist_t * yy145;
  struct table_t * yy175;
  struct select_limit_t * yy245;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#if INTERFACE
#define logfilterParserARG_SDECL  struct logfilterParserParams *pargs ;
#define logfilterParserARG_PDECL , struct logfilterParserParams *pargs 
#define logfilterParserARG_FETCH  struct logfilterParserParams *pargs  = yypParser->pargs 
#define logfilterParserARG_STORE yypParser->pargs  = pargs 
#endif
#define YYNSTATE 100
#define YYNRULE 68
#define YYFALLBACK 1
#define YY_NO_ACTION      (YYNSTATE+YYNRULE+2)
#define YY_ACCEPT_ACTION  (YYNSTATE+YYNRULE+1)
#define YY_ERROR_ACTION   (YYNSTATE+YYNRULE)

/* The yyzerominor constant is used to initialize instances of
** YYMINORTYPE objects to zero. */
static const YYMINORTYPE yyzerominor = { 0 };

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N < YYNSTATE                  Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   YYNSTATE <= N < YYNSTATE+YYNRULE   Reduce by rule N-YYNSTATE.
**
**   N == YYNSTATE+YYNRULE              A syntax error has occurred.
**
**   N == YYNSTATE+YYNRULE+1            The parser accepts its input.
**
**   N == YYNSTATE+YYNRULE+2            No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as
**
**      yy_action[ yy_shift_ofst[S] + X ]
**
** If the index value yy_shift_ofst[S]+X is out of range or if the value
** yy_lookahead[yy_shift_ofst[S]+X] is not equal to X or if yy_shift_ofst[S]
** is equal to YY_SHIFT_USE_DFLT, it means that the action is not in the table
** and that yy_default[S] should be used instead.  
**
** The formula above is for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
*/
#define YY_ACTTAB_COUNT (430)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */    81,   81,   32,   32,   32,   31,  102,   42,   30,   28,
 /*    10 */    23,   71,   38,   38,   38,   38,   27,   35,   35,   35,
 /*    20 */    35,   34,   33,   32,   32,   32,   31,  169,   72,   54,
 /*    30 */    39,   41,   69,   25,   79,   86,   80,   80,   37,   37,
 /*    40 */    38,   38,   38,   38,   96,   35,   35,   35,   35,   34,
 /*    50 */    33,   32,   32,   32,   31,   73,   78,   55,   77,   53,
 /*    60 */    14,   81,   81,   85,   30,   28,   23,   75,   38,   38,
 /*    70 */    38,   38,   71,   35,   35,   35,   35,   34,   33,   32,
 /*    80 */    32,   32,   31,   57,   99,   98,   64,   56,   66,   58,
 /*    90 */    12,   39,   41,   69,   25,   79,   65,   80,   80,   37,
 /*   100 */    37,   38,   38,   38,   38,   62,   35,   35,   35,   35,
 /*   110 */    34,   33,   32,   32,   32,   31,   63,   60,   61,   67,
 /*   120 */    13,   81,   81,   76,   97,   43,   93,   59,   68,   74,
 /*   130 */    95,   31,   71,  170,  170,   35,   35,   35,   35,   34,
 /*   140 */    33,   32,   32,   32,   31,  170,  170,  170,  170,  170,
 /*   150 */   170,   39,   41,   69,   25,   79,  170,   80,   80,   37,
 /*   160 */    37,   38,   38,   38,   38,   91,   35,   35,   35,   35,
 /*   170 */    34,   33,   32,   32,   32,   31,   91,  170,   91,   91,
 /*   180 */     2,   81,   81,   34,   33,   32,   32,   32,   31,   94,
 /*   190 */   170,    7,   71,    9,    3,  170,  170,  170,  170,  170,
 /*   200 */    94,  170,   94,   94,  170,   81,   81,  170,  170,  170,
 /*   210 */   170,   39,   22,   69,   25,   79,   71,   80,   80,   37,
 /*   220 */    37,   38,   38,   38,   38,   91,   35,   35,   35,   35,
 /*   230 */    34,   33,   32,   32,   32,   31,   41,   69,   25,   79,
 /*   240 */     8,   80,   80,   37,   37,   38,   38,   38,   38,   94,
 /*   250 */    35,   35,   35,   35,   34,   33,   32,   32,   32,   31,
 /*   260 */    81,   81,   96,   91,   91,   91,   91,   91,  170,  170,
 /*   270 */   170,   71,  170,  170,  170,  170,  170,  170,   44,   36,
 /*   280 */    45,   47,   46,  170,  170,  170,  170,   94,   94,   94,
 /*   290 */    94,   94,   69,   25,   79,   96,   80,   80,   37,   37,
 /*   300 */    38,   38,   38,   38,  170,   35,   35,   35,   35,   34,
 /*   310 */    33,   32,   32,   32,   31,  170,  170,   87,   91,   91,
 /*   320 */    91,   91,   20,  170,  170,  170,  170,  170,  170,  170,
 /*   330 */    84,   84,  170,   48,   52,   29,   11,   91,   91,   17,
 /*   340 */    18,   70,   94,   94,   94,   94,   19,   89,   95,  170,
 /*   350 */    87,   91,   26,   24,   40,   16,   92,   90,   90,   90,
 /*   360 */    88,   94,   94,  170,   82,  170,    6,  170,  170,  170,
 /*   370 */    91,  170,   17,   18,  170,   94,  170,  170,  170,   19,
 /*   380 */    89,   95,   91,   91,   91,   21,  170,   40,  170,   92,
 /*   390 */    90,   90,   90,   88,   94,   91,   83,   10,   51,   50,
 /*   400 */    91,   91,   91,  170,  170,   91,   94,   94,   94,  170,
 /*   410 */    49,  170,  170,  170,  170,   15,    5,    4,  170,   94,
 /*   420 */     1,  170,  170,  170,   94,   94,   94,  170,  170,   94,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */    29,   30,   80,   81,   82,   83,    0,   36,  127,  128,
 /*    10 */   129,   40,   69,   70,   71,   72,   73,   74,   75,   76,
 /*    20 */    77,   78,   79,   80,   81,   82,   83,  103,  104,  105,
 /*    30 */    59,   60,   61,   62,   63,  100,   65,   66,   67,   68,
 /*    40 */    69,   70,   71,   72,    1,   74,   75,   76,   77,   78,
 /*    50 */    79,   80,   81,   82,   83,  118,   89,   90,  119,  120,
 /*    60 */    89,   29,   30,  100,  127,  128,  129,  102,   69,   70,
 /*    70 */    71,   72,   40,   74,   75,   76,   77,   78,   79,   80,
 /*    80 */    81,   82,   83,  109,  106,  107,  121,  108,  112,  114,
 /*    90 */   116,   59,   60,   61,   62,   63,  113,   65,   66,   67,
 /*   100 */    68,   69,   70,   71,   72,  118,   74,   75,   76,   77,
 /*   110 */    78,   79,   80,   81,   82,   83,  122,  124,  123,  111,
 /*   120 */    92,   29,   30,  125,  115,   91,   94,  110,   88,   86,
 /*   130 */    87,   83,   40,  130,  130,   74,   75,   76,   77,   78,
 /*   140 */    79,   80,   81,   82,   83,  130,  130,  130,  130,  130,
 /*   150 */   130,   59,   60,   61,   62,   63,  130,   65,   66,   67,
 /*   160 */    68,   69,   70,   71,   72,  102,   74,   75,   76,   77,
 /*   170 */    78,   79,   80,   81,   82,   83,  102,  130,  102,  102,
 /*   180 */   117,   29,   30,   78,   79,   80,   81,   82,   83,  126,
 /*   190 */   130,  117,   40,  117,  117,  130,  130,  130,  130,  130,
 /*   200 */   126,  130,  126,  126,  130,   29,   30,  130,  130,  130,
 /*   210 */   130,   59,   60,   61,   62,   63,   40,   65,   66,   67,
 /*   220 */    68,   69,   70,   71,   72,  102,   74,   75,   76,   77,
 /*   230 */    78,   79,   80,   81,   82,   83,   60,   61,   62,   63,
 /*   240 */   117,   65,   66,   67,   68,   69,   70,   71,   72,  126,
 /*   250 */    74,   75,   76,   77,   78,   79,   80,   81,   82,   83,
 /*   260 */    29,   30,    1,  102,  102,  102,  102,  102,  130,  130,
 /*   270 */   130,   40,  130,  130,  130,  130,  130,  130,  117,  117,
 /*   280 */   117,  117,  117,  130,  130,  130,  130,  126,  126,  126,
 /*   290 */   126,  126,   61,   62,   63,    1,   65,   66,   67,   68,
 /*   300 */    69,   70,   71,   72,  130,   74,   75,   76,   77,   78,
 /*   310 */    79,   80,   81,   82,   83,  130,  130,   56,  102,  102,
 /*   320 */   102,  102,   61,  130,  130,  130,  130,  130,  130,  130,
 /*   330 */    29,   30,  130,  117,  117,  117,  117,  102,  102,   78,
 /*   340 */    79,   40,  126,  126,  126,  126,   85,   86,   87,  130,
 /*   350 */    56,  102,  117,  117,   93,   61,   95,   96,   97,   98,
 /*   360 */    99,  126,  126,  130,   63,  130,  117,  130,  130,  130,
 /*   370 */   102,  130,   78,   79,  130,  126,  130,  130,  130,   85,
 /*   380 */    86,   87,  102,  102,  102,  117,  130,   93,  130,   95,
 /*   390 */    96,   97,   98,   99,  126,  102,   95,  117,  117,  117,
 /*   400 */   102,  102,  102,  130,  130,  102,  126,  126,  126,  130,
 /*   410 */   117,  130,  130,  130,  130,  117,  117,  117,  130,  126,
 /*   420 */   117,  130,  130,  130,  126,  126,  126,  130,  130,  126,
};
#define YY_SHIFT_USE_DFLT (-79)
#define YY_SHIFT_COUNT (72)
#define YY_SHIFT_MIN   (-78)
#define YY_SHIFT_MAX   (301)
static const short yy_shift_ofst[] = {
 /*     0 */   -79,   92,  -29,   32,   92,   92,  152,   92,  176,  231,
 /*    10 */   231,  -57,  261,  261,  261,   -1,  261,  261,  261,  261,
 /*    20 */   261,   -1,  261,  261,   -1,  294,   -1,  261,  261,   -1,
 /*    30 */   261,  261,  261,  261,  261,  261,   -1,  261,  261,  261,
 /*    40 */   261,  261,  261,  261,   61,  105,  -78,  -78,   48,  -79,
 /*    50 */   -79,  -79,  -79,   43,   40,  -79,  -79,  -33,   34,   28,
 /*    60 */   -79,  -79,  -79,  -79,  -79,  -79,  -79,  -79,  -79,  301,
 /*    70 */   -37,  -65,    6,
};
#define YY_REDUCE_USE_DFLT (-120)
#define YY_REDUCE_COUNT (68)
#define YY_REDUCE_MIN   (-119)
#define YY_REDUCE_MAX   (303)
static const short yy_reduce_ofst[] = {
 /*     0 */   -76,  -63, -119, -119, -119, -119, -119, -119, -119, -119,
 /*    10 */  -119, -119,  303,  300,  299, -119,  298,  293,  282,  281,
 /*    20 */   280, -119,  268,  249, -119,  236, -119,  235,  219, -119,
 /*    30 */   218,  217,  216,  165,  164,  163, -119,  162,  161,  123,
 /*    40 */    77,   76,   74,   63, -119, -119, -119, -119, -119, -119,
 /*    50 */  -119, -119, -119,  -35,  -22,  -61,  -26,   17,    9,    8,
 /*    60 */    -2,   -7,   -5,  -13,   -6,  -25,  -17,  -24,  -21,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */   126,  110,  123,  168,  130,  125,  168,  124,  140,  139,
 /*    10 */   161,  155,  168,  168,  168,  160,  168,  168,  168,  168,
 /*    20 */   168,  167,  168,  168,  159,  168,  156,  168,  168,  152,
 /*    30 */   168,  168,  168,  168,  168,  168,  142,  168,  168,  168,
 /*    40 */   168,  168,  168,  168,  141,  143,  145,  144,  146,  164,
 /*    50 */   163,  162,  147,  168,  168,  113,  108,  111,  122,  129,
 /*    60 */   118,  116,  117,  110,  115,  119,  121,  120,  106,  168,
 /*    70 */   149,  148,  168,  109,  128,  127,  114,  112,  107,  165,
 /*    80 */   157,  153,  166,  158,  154,  151,  150,  138,  137,  136,
 /*    90 */   135,  134,  133,  132,  131,  101,  100,  105,  104,  103,
};

/* The next table maps tokens into fallback tokens.  If a construct
** like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*         ID => nothing */
    1,  /*      ABORT => ID */
    1,  /*     ACTION => ID */
    1,  /*      AFTER => ID */
    1,  /*    ANALYZE => ID */
    1,  /*        ASC => ID */
    1,  /*     ATTACH => ID */
    1,  /*     BEFORE => ID */
    1,  /*      BEGIN => ID */
    1,  /*         BY => ID */
    1,  /*    CASCADE => ID */
    1,  /*       CAST => ID */
    1,  /*   COLUMNKW => ID */
    1,  /*   CONFLICT => ID */
    1,  /*   DATABASE => ID */
    1,  /*   DEFERRED => ID */
    1,  /*       DESC => ID */
    1,  /*     DETACH => ID */
    1,  /*       EACH => ID */
    1,  /*        END => ID */
    1,  /*  EXCLUSIVE => ID */
    1,  /*    EXPLAIN => ID */
    1,  /*       FAIL => ID */
    1,  /*        FOR => ID */
    1,  /*     IGNORE => ID */
    1,  /*  IMMEDIATE => ID */
    1,  /*  INITIALLY => ID */
    1,  /*    INSTEAD => ID */
    1,  /*    LIKE_KW => ID */
    1,  /*      MATCH => ID */
    1,  /*         NO => ID */
    1,  /*       PLAN => ID */
    1,  /*      QUERY => ID */
    1,  /*        KEY => ID */
    1,  /*         OF => ID */
    1,  /*     OFFSET => ID */
    1,  /*     PRAGMA => ID */
    1,  /*      RAISE => ID */
    1,  /*  RECURSIVE => ID */
    1,  /*     REGEXP => ID */
    1,  /*    RELEASE => ID */
    1,  /*    REPLACE => ID */
    1,  /*   RESTRICT => ID */
    1,  /*        ROW => ID */
    1,  /*   ROLLBACK => ID */
    1,  /*  SAVEPOINT => ID */
    1,  /*       TEMP => ID */
    1,  /*    TRIGGER => ID */
    1,  /*     VACUUM => ID */
    1,  /*       VIEW => ID */
    1,  /*    VIRTUAL => ID */
    1,  /*       WITH => ID */
    1,  /*    WITHOUT => ID */
    1,  /*    REINDEX => ID */
    1,  /*     RENAME => ID */
    1,  /*   CTIME_KW => ID */
    1,  /*         IF => ID */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  int yyidx;                    /* Index of top element in stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyidxMax;                 /* Maximum value of yyidx */
#endif
  int yyerrcnt;                 /* Shifts left before out of the error */
  logfilterParserARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void logfilterParserTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "ID",            "ABORT",         "ACTION",      
  "AFTER",         "ANALYZE",       "ASC",           "ATTACH",      
  "BEFORE",        "BEGIN",         "BY",            "CASCADE",     
  "CAST",          "COLUMNKW",      "CONFLICT",      "DATABASE",    
  "DEFERRED",      "DESC",          "DETACH",        "EACH",        
  "END",           "EXCLUSIVE",     "EXPLAIN",       "FAIL",        
  "FOR",           "IGNORE",        "IMMEDIATE",     "INITIALLY",   
  "INSTEAD",       "LIKE_KW",       "MATCH",         "NO",          
  "PLAN",          "QUERY",         "KEY",           "OF",          
  "OFFSET",        "PRAGMA",        "RAISE",         "RECURSIVE",   
  "REGEXP",        "RELEASE",       "REPLACE",       "RESTRICT",    
  "ROW",           "ROLLBACK",      "SAVEPOINT",     "TEMP",        
  "TRIGGER",       "VACUUM",        "VIEW",          "VIRTUAL",     
  "WITH",          "WITHOUT",       "REINDEX",       "RENAME",      
  "CTIME_KW",      "IF",            "ANY",           "OR",          
  "AND",           "NOT",           "IS",            "BETWEEN",     
  "IN",            "ISNULL",        "NOTNULL",       "NE",          
  "EQ",            "GT",            "LE",            "LT",          
  "GE",            "ESCAPE",        "BITAND",        "BITOR",       
  "LSHIFT",        "RSHIFT",        "PLUS",          "MINUS",       
  "STAR",          "SLASH",         "REM",           "CONCAT",      
  "COLLATE",       "BITNOT",        "STRING",        "INDEXED",     
  "SELECT",        "COMMA",         "FROM",          "LIMIT",       
  "WHERE",         "LP",            "RP",            "NULL",        
  "INTEGER",       "FLOAT",         "BLOB",          "VARIABLE",    
  "BINARY",        "error",         "id",            "cmd",         
  "select",        "with",          "selectnowith",  "oneselect",   
  "distinct",      "selcollist",    "from",          "where_opt",   
  "groupby_opt",   "having_opt",    "orderby_opt",   "limit_opt",   
  "sclp",          "expr",          "as",            "seltablist",  
  "stl_prefix",    "nm",            "dbnm",          "indexed_opt", 
  "on_opt",        "using_opt",     "term",          "regexpop",    
  "likeop",        "between_op",  
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "id ::= ID",
 /*   1 */ "id ::= INDEXED",
 /*   2 */ "cmd ::= select",
 /*   3 */ "select ::= with selectnowith",
 /*   4 */ "selectnowith ::= oneselect",
 /*   5 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt",
 /*   6 */ "distinct ::=",
 /*   7 */ "sclp ::= selcollist COMMA",
 /*   8 */ "sclp ::=",
 /*   9 */ "selcollist ::= sclp expr as",
 /*  10 */ "as ::=",
 /*  11 */ "from ::=",
 /*  12 */ "from ::= FROM seltablist",
 /*  13 */ "stl_prefix ::=",
 /*  14 */ "seltablist ::= stl_prefix nm dbnm as indexed_opt on_opt using_opt",
 /*  15 */ "dbnm ::=",
 /*  16 */ "on_opt ::=",
 /*  17 */ "indexed_opt ::=",
 /*  18 */ "using_opt ::=",
 /*  19 */ "orderby_opt ::=",
 /*  20 */ "groupby_opt ::=",
 /*  21 */ "having_opt ::=",
 /*  22 */ "limit_opt ::=",
 /*  23 */ "limit_opt ::= LIMIT expr",
 /*  24 */ "limit_opt ::= LIMIT expr OFFSET expr",
 /*  25 */ "limit_opt ::= LIMIT expr COMMA expr",
 /*  26 */ "with ::=",
 /*  27 */ "nm ::= id",
 /*  28 */ "nm ::= STRING",
 /*  29 */ "where_opt ::=",
 /*  30 */ "where_opt ::= WHERE expr",
 /*  31 */ "expr ::= term",
 /*  32 */ "expr ::= LP expr RP",
 /*  33 */ "term ::= NULL",
 /*  34 */ "expr ::= id",
 /*  35 */ "term ::= INTEGER|FLOAT|BLOB",
 /*  36 */ "term ::= STRING",
 /*  37 */ "expr ::= VARIABLE",
 /*  38 */ "term ::= CTIME_KW",
 /*  39 */ "expr ::= expr AND expr",
 /*  40 */ "expr ::= expr OR expr",
 /*  41 */ "expr ::= expr LT|GT|GE|LE expr",
 /*  42 */ "expr ::= expr EQ|NE expr",
 /*  43 */ "expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr",
 /*  44 */ "expr ::= expr PLUS expr",
 /*  45 */ "expr ::= expr MINUS expr",
 /*  46 */ "expr ::= expr STAR|SLASH|REM expr",
 /*  47 */ "expr ::= expr CONCAT expr",
 /*  48 */ "regexpop ::= REGEXP",
 /*  49 */ "regexpop ::= NOT REGEXP",
 /*  50 */ "regexpop ::= REGEXP BINARY",
 /*  51 */ "regexpop ::= NOT REGEXP BINARY",
 /*  52 */ "expr ::= expr regexpop expr",
 /*  53 */ "likeop ::= LIKE_KW|MATCH",
 /*  54 */ "likeop ::= NOT LIKE_KW|MATCH",
 /*  55 */ "expr ::= expr likeop expr",
 /*  56 */ "expr ::= expr likeop expr ESCAPE expr",
 /*  57 */ "expr ::= expr ISNULL|NOTNULL",
 /*  58 */ "expr ::= expr NOT NULL",
 /*  59 */ "expr ::= expr IS expr",
 /*  60 */ "expr ::= expr IS NOT expr",
 /*  61 */ "expr ::= NOT expr",
 /*  62 */ "expr ::= BITNOT expr",
 /*  63 */ "expr ::= MINUS expr",
 /*  64 */ "expr ::= PLUS expr",
 /*  65 */ "between_op ::= BETWEEN",
 /*  66 */ "between_op ::= NOT BETWEEN",
 /*  67 */ "expr ::= expr between_op expr AND expr",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.
*/
static void yyGrowStack(yyParser *p){
  int newSize;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  if( pNew ){
    p->yystack = pNew;
    p->yystksz = newSize;
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows to %d entries!\n",
              yyTracePrompt, p->yystksz);
    }
#endif
  }
}
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to logfilterParser and logfilterParserFree.
*/
void *logfilterParserAlloc(void *(*mallocProc)(size_t)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (size_t)sizeof(yyParser) );
  if( pParser ){
    pParser->yyidx = -1;
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyidxMax = 0;
#endif
#if YYSTACKDEPTH<=0
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    yyGrowStack(pParser);
#endif
  }
  return pParser;
}

/* The following function deletes the value associated with a
** symbol.  The symbol can be either a terminal or nonterminal.
** "yymajor" is the symbol code, and "yypminor" is a pointer to
** the value.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  logfilterParserARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are not used
    ** inside the C code.
    */
      /* TERMINAL Destructor */
    case 1: /* ID */
    case 2: /* ABORT */
    case 3: /* ACTION */
    case 4: /* AFTER */
    case 5: /* ANALYZE */
    case 6: /* ASC */
    case 7: /* ATTACH */
    case 8: /* BEFORE */
    case 9: /* BEGIN */
    case 10: /* BY */
    case 11: /* CASCADE */
    case 12: /* CAST */
    case 13: /* COLUMNKW */
    case 14: /* CONFLICT */
    case 15: /* DATABASE */
    case 16: /* DEFERRED */
    case 17: /* DESC */
    case 18: /* DETACH */
    case 19: /* EACH */
    case 20: /* END */
    case 21: /* EXCLUSIVE */
    case 22: /* EXPLAIN */
    case 23: /* FAIL */
    case 24: /* FOR */
    case 25: /* IGNORE */
    case 26: /* IMMEDIATE */
    case 27: /* INITIALLY */
    case 28: /* INSTEAD */
    case 29: /* LIKE_KW */
    case 30: /* MATCH */
    case 31: /* NO */
    case 32: /* PLAN */
    case 33: /* QUERY */
    case 34: /* KEY */
    case 35: /* OF */
    case 36: /* OFFSET */
    case 37: /* PRAGMA */
    case 38: /* RAISE */
    case 39: /* RECURSIVE */
    case 40: /* REGEXP */
    case 41: /* RELEASE */
    case 42: /* REPLACE */
    case 43: /* RESTRICT */
    case 44: /* ROW */
    case 45: /* ROLLBACK */
    case 46: /* SAVEPOINT */
    case 47: /* TEMP */
    case 48: /* TRIGGER */
    case 49: /* VACUUM */
    case 50: /* VIEW */
    case 51: /* VIRTUAL */
    case 52: /* WITH */
    case 53: /* WITHOUT */
    case 54: /* REINDEX */
    case 55: /* RENAME */
    case 56: /* CTIME_KW */
    case 57: /* IF */
    case 58: /* ANY */
    case 59: /* OR */
    case 60: /* AND */
    case 61: /* NOT */
    case 62: /* IS */
    case 63: /* BETWEEN */
    case 64: /* IN */
    case 65: /* ISNULL */
    case 66: /* NOTNULL */
    case 67: /* NE */
    case 68: /* EQ */
    case 69: /* GT */
    case 70: /* LE */
    case 71: /* LT */
    case 72: /* GE */
    case 73: /* ESCAPE */
    case 74: /* BITAND */
    case 75: /* BITOR */
    case 76: /* LSHIFT */
    case 77: /* RSHIFT */
    case 78: /* PLUS */
    case 79: /* MINUS */
    case 80: /* STAR */
    case 81: /* SLASH */
    case 82: /* REM */
    case 83: /* CONCAT */
    case 84: /* COLLATE */
    case 85: /* BITNOT */
    case 86: /* STRING */
    case 87: /* INDEXED */
    case 88: /* SELECT */
    case 89: /* COMMA */
    case 90: /* FROM */
    case 91: /* LIMIT */
    case 92: /* WHERE */
    case 93: /* LP */
    case 94: /* RP */
    case 95: /* NULL */
    case 96: /* INTEGER */
    case 97: /* FLOAT */
    case 98: /* BLOB */
    case 99: /* VARIABLE */
    case 100: /* BINARY */
{
#line 7 "sqlextract/parser.ly"

	if((yypminor->yy0)) free((yypminor->yy0));
	if(pargs) {} /* compiler warns for unused variable otherwise */

#line 862 "sqlextract/parser.c"
}
      break;
    case 102: /* id */
    case 121: /* nm */
{
#line 87 "sqlextract/parser.ly"
free((yypminor->yy33));
#line 870 "sqlextract/parser.c"
}
      break;
    case 103: /* cmd */
    case 104: /* select */
    case 106: /* selectnowith */
    case 107: /* oneselect */
{
#line 107 "sqlextract/parser.ly"
command_destroy((yypminor->yy2));
#line 880 "sqlextract/parser.c"
}
      break;
    case 109: /* selcollist */
    case 116: /* sclp */
{
#line 159 "sqlextract/parser.ly"

	selcollist_destroy((yypminor->yy145));

#line 890 "sqlextract/parser.c"
}
      break;
    case 110: /* from */
{
#line 175 "sqlextract/parser.ly"


#line 898 "sqlextract/parser.c"
}
      break;
    case 111: /* where_opt */
    case 117: /* expr */
{
#line 283 "sqlextract/parser.ly"
filter_destroy((yypminor->yy61));
#line 906 "sqlextract/parser.c"
}
      break;
    case 115: /* limit_opt */
{
#line 242 "sqlextract/parser.ly"

	select_limit_destroy((yypminor->yy245));

#line 915 "sqlextract/parser.c"
}
      break;
    case 119: /* seltablist */
{
#line 191 "sqlextract/parser.ly"

	table_destroy((yypminor->yy175));

#line 924 "sqlextract/parser.c"
}
      break;
    case 126: /* term */
{
#line 300 "sqlextract/parser.ly"
arbval_destroy((yypminor->yy67));
#line 931 "sqlextract/parser.c"
}
      break;
    case 127: /* regexpop */
    case 128: /* likeop */
    case 129: /* between_op */
{
#line 399 "sqlextract/parser.ly"

#line 940 "sqlextract/parser.c"
}
      break;
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
**
** Return the major token number for the symbol popped.
*/
static int yy_pop_parser_stack(yyParser *pParser){
  YYCODETYPE yymajor;
  yyStackEntry *yytos = &pParser->yystack[pParser->yyidx];

  if( pParser->yyidx<0 ) return 0;
#ifndef NDEBUG
  if( yyTraceFILE && pParser->yyidx>=0 ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yymajor = yytos->major;
  yy_destructor(pParser, yymajor, &yytos->minor);
  pParser->yyidx--;
  return yymajor;
}

/* 
** Deallocate and destroy a parser.  Destructors are all called for
** all stack elements before shutting the parser down.
**
** Inputs:
** <ul>
** <li>  A pointer to the parser.  This should be a pointer
**       obtained from logfilterParserAlloc.
** <li>  A pointer to a function used to reclaim memory obtained
**       from malloc.
** </ul>
*/
void logfilterParserFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
  if( pParser==0 ) return;
  while( pParser->yyidx>=0 ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int logfilterParserStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyidxMax;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yystack[pParser->yyidx].stateno;
 
  if( stateno>YY_SHIFT_COUNT
   || (i = yy_shift_ofst[stateno])==YY_SHIFT_USE_DFLT ){
    return yy_default[stateno];
  }
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    if( iLookAhead>0 ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        return yy_find_shift_action(pParser, iFallback);
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
    }
    return yy_default[stateno];
  }else{
    return yy_action[i];
  }
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser, YYMINORTYPE *yypMinor){
   logfilterParserARG_FETCH;
   yypParser->yyidx--;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
   logfilterParserARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  YYMINORTYPE *yypMinor         /* Pointer to the minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yyidx++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( yypParser->yyidx>yypParser->yyidxMax ){
    yypParser->yyidxMax = yypParser->yyidx;
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yyidx>=YYSTACKDEPTH ){
    yyStackOverflow(yypParser, yypMinor);
    return;
  }
#else
  if( yypParser->yyidx>=yypParser->yystksz ){
    yyGrowStack(yypParser);
    if( yypParser->yyidx>=yypParser->yystksz ){
      yyStackOverflow(yypParser, yypMinor);
      return;
    }
  }
#endif
  yytos = &yypParser->yystack[yypParser->yyidx];
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor = *yypMinor;
#ifndef NDEBUG
  if( yyTraceFILE && yypParser->yyidx>0 ){
    int i;
    fprintf(yyTraceFILE,"%sShift %d\n",yyTracePrompt,yyNewState);
    fprintf(yyTraceFILE,"%sStack:",yyTracePrompt);
    for(i=1; i<=yypParser->yyidx; i++)
      fprintf(yyTraceFILE," %s",yyTokenName[yypParser->yystack[i].major]);
    fprintf(yyTraceFILE,"\n");
  }
#endif
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 102, 1 },
  { 102, 1 },
  { 103, 1 },
  { 104, 2 },
  { 106, 1 },
  { 107, 9 },
  { 108, 0 },
  { 116, 2 },
  { 116, 0 },
  { 109, 3 },
  { 118, 0 },
  { 110, 0 },
  { 110, 2 },
  { 120, 0 },
  { 119, 7 },
  { 122, 0 },
  { 124, 0 },
  { 123, 0 },
  { 125, 0 },
  { 114, 0 },
  { 112, 0 },
  { 113, 0 },
  { 115, 0 },
  { 115, 2 },
  { 115, 4 },
  { 115, 4 },
  { 105, 0 },
  { 121, 1 },
  { 121, 1 },
  { 111, 0 },
  { 111, 2 },
  { 117, 1 },
  { 117, 3 },
  { 126, 1 },
  { 117, 1 },
  { 126, 1 },
  { 126, 1 },
  { 117, 1 },
  { 126, 1 },
  { 117, 3 },
  { 117, 3 },
  { 117, 3 },
  { 117, 3 },
  { 117, 3 },
  { 117, 3 },
  { 117, 3 },
  { 117, 3 },
  { 117, 3 },
  { 127, 1 },
  { 127, 2 },
  { 127, 2 },
  { 127, 3 },
  { 117, 3 },
  { 128, 1 },
  { 128, 2 },
  { 117, 3 },
  { 117, 5 },
  { 117, 2 },
  { 117, 3 },
  { 117, 3 },
  { 117, 4 },
  { 117, 2 },
  { 117, 2 },
  { 117, 2 },
  { 117, 2 },
  { 129, 1 },
  { 129, 2 },
  { 117, 5 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  int yyruleno                 /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  YYMINORTYPE yygotominor;        /* The LHS of the rule reduced */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  logfilterParserARG_FETCH;
  yymsp = &yypParser->yystack[yypParser->yyidx];
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno>=0 
        && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    fprintf(yyTraceFILE, "%sReduce [%s].\n", yyTracePrompt,
      yyRuleName[yyruleno]);
  }
#endif /* NDEBUG */

  /* Silence complaints from purify about yygotominor being uninitialized
  ** in some cases when it is copied into the stack after the following
  ** switch.  yygotominor is uninitialized when a rule reduces that does
  ** not set the value of its left-hand side nonterminal.  Leaving the
  ** value of the nonterminal uninitialized is utterly harmless as long
  ** as the value is never used.  So really the only thing this code
  ** accomplishes is to quieten purify.  
  **
  ** 2007-01-16:  The wireshark project (www.wireshark.org) reports that
  ** without this code, their parser segfaults.  I'm not sure what there
  ** parser is doing to make this happen.  This is the second bug report
  ** from wireshark this week.  Clearly they are stressing Lemon in ways
  ** that it has not been previously stressed...  (SQLite ticket #2172)
  */
  /*memset(&yygotominor, 0, sizeof(yygotominor));*/
  yygotominor = yyzerominor;


  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
      case 0: /* id ::= ID */
#line 89 "sqlextract/parser.ly"
{
	if(*yymsp[0].minor.yy0 == '\"') {
		yygotominor.yy33 = strdup_unescape(yymsp[0].minor.yy0);
		free(yymsp[0].minor.yy0);
	} else {
		yygotominor.yy33 = yymsp[0].minor.yy0;
	}
}
#line 1310 "sqlextract/parser.c"
        break;
      case 1: /* id ::= INDEXED */
#line 97 "sqlextract/parser.ly"
{
	yygotominor.yy33 = lf_strdup(yymsp[0].minor.yy0);
}
#line 1317 "sqlextract/parser.c"
        break;
      case 2: /* cmd ::= select */
#line 109 "sqlextract/parser.ly"
{
	pargs->command = yymsp[0].minor.yy2;
}
#line 1324 "sqlextract/parser.c"
        break;
      case 3: /* select ::= with selectnowith */
      case 4: /* selectnowith ::= oneselect */ yytestcase(yyruleno==4);
#line 117 "sqlextract/parser.ly"
{
	yygotominor.yy2 = yymsp[0].minor.yy2;
}
#line 1332 "sqlextract/parser.c"
        break;
      case 5: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt */
#line 132 "sqlextract/parser.ly"
{
	yygotominor.yy2 = command_select_create(yymsp[-6].minor.yy145, yymsp[-4].minor.yy61, yymsp[-5].minor.yy175, yymsp[0].minor.yy245);
  yy_destructor(yypParser,88,&yymsp[-8].minor);
}
#line 1340 "sqlextract/parser.c"
        break;
      case 7: /* sclp ::= selcollist COMMA */
#line 151 "sqlextract/parser.ly"
{
	yygotominor.yy145 = yymsp[-1].minor.yy145;
  yy_destructor(yypParser,89,&yymsp[0].minor);
}
#line 1348 "sqlextract/parser.c"
        break;
      case 8: /* sclp ::= */
#line 154 "sqlextract/parser.ly"
{
	yygotominor.yy145 = NULL;
}
#line 1355 "sqlextract/parser.c"
        break;
      case 9: /* selcollist ::= sclp expr as */
#line 163 "sqlextract/parser.ly"
{
	yygotominor.yy145 = selcollist_create(yymsp[-2].minor.yy145, yymsp[-1].minor.yy61);
}
#line 1362 "sqlextract/parser.c"
        break;
      case 11: /* from ::= */
#line 178 "sqlextract/parser.ly"
{
	yygotominor.yy175 = pargs->table_singlerow;
}
#line 1369 "sqlextract/parser.c"
        break;
      case 12: /* from ::= FROM seltablist */
#line 181 "sqlextract/parser.ly"
{
	yygotominor.yy175 = yymsp[0].minor.yy175;
  yy_destructor(yypParser,90,&yymsp[-1].minor);
}
#line 1377 "sqlextract/parser.c"
        break;
      case 14: /* seltablist ::= stl_prefix nm dbnm as indexed_opt on_opt using_opt */
#line 196 "sqlextract/parser.ly"
{
	yygotominor.yy175 = tablespace_get(pargs->tablespace, strid_get(pargs->si, yymsp[-5].minor.yy33));
	free(yymsp[-5].minor.yy33);
}
#line 1385 "sqlextract/parser.c"
        break;
      case 22: /* limit_opt ::= */
#line 246 "sqlextract/parser.ly"
{
	yygotominor.yy245 = NULL;
}
#line 1392 "sqlextract/parser.c"
        break;
      case 23: /* limit_opt ::= LIMIT expr */
#line 249 "sqlextract/parser.ly"
{
	struct arbval_t *zero = arbval_create_integer(0);
	yygotominor.yy245 = select_limit_create(yymsp[0].minor.yy61, filter_create_constant(zero));
	arbval_destroy(zero);
  yy_destructor(yypParser,91,&yymsp[-1].minor);
}
#line 1402 "sqlextract/parser.c"
        break;
      case 24: /* limit_opt ::= LIMIT expr OFFSET expr */
#line 254 "sqlextract/parser.ly"
{
	yygotominor.yy245 = select_limit_create(yymsp[-2].minor.yy61, yymsp[0].minor.yy61);
  yy_destructor(yypParser,91,&yymsp[-3].minor);
  yy_destructor(yypParser,36,&yymsp[-1].minor);
}
#line 1411 "sqlextract/parser.c"
        break;
      case 25: /* limit_opt ::= LIMIT expr COMMA expr */
#line 257 "sqlextract/parser.ly"
{
	yygotominor.yy245 = select_limit_create(yymsp[0].minor.yy61, yymsp[-2].minor.yy61);
  yy_destructor(yypParser,91,&yymsp[-3].minor);
  yy_destructor(yypParser,89,&yymsp[-1].minor);
}
#line 1420 "sqlextract/parser.c"
        break;
      case 27: /* nm ::= id */
#line 269 "sqlextract/parser.ly"
{
	yygotominor.yy33 = yymsp[0].minor.yy33;
}
#line 1427 "sqlextract/parser.c"
        break;
      case 28: /* nm ::= STRING */
#line 272 "sqlextract/parser.ly"
{
	yygotominor.yy33 = strdup_unescape(yymsp[0].minor.yy0);
	free(yymsp[0].minor.yy0);
}
#line 1435 "sqlextract/parser.c"
        break;
      case 29: /* where_opt ::= */
#line 285 "sqlextract/parser.ly"
{
	struct arbval_t *av = arbval_create_integer(1);
	yygotominor.yy61 = filter_create_constant(av);
	arbval_destroy(av);
}
#line 1444 "sqlextract/parser.c"
        break;
      case 30: /* where_opt ::= WHERE expr */
#line 290 "sqlextract/parser.ly"
{
	yygotominor.yy61 = yymsp[0].minor.yy61;
  yy_destructor(yypParser,92,&yymsp[-1].minor);
}
#line 1452 "sqlextract/parser.c"
        break;
      case 31: /* expr ::= term */
#line 302 "sqlextract/parser.ly"
{
	yygotominor.yy61 = filter_create_constant(yymsp[0].minor.yy67);
	arbval_destroy(yymsp[0].minor.yy67);
}
#line 1460 "sqlextract/parser.c"
        break;
      case 32: /* expr ::= LP expr RP */
#line 306 "sqlextract/parser.ly"
{
	yygotominor.yy61 = yymsp[-1].minor.yy61;
  yy_destructor(yypParser,93,&yymsp[-2].minor);
  yy_destructor(yypParser,94,&yymsp[0].minor);
}
#line 1469 "sqlextract/parser.c"
        break;
      case 33: /* term ::= NULL */
#line 309 "sqlextract/parser.ly"
{
	yygotominor.yy67 = arbval_create_null();
  yy_destructor(yypParser,95,&yymsp[0].minor);
}
#line 1477 "sqlextract/parser.c"
        break;
      case 34: /* expr ::= id */
#line 312 "sqlextract/parser.ly"
{
	yygotominor.yy61 = filter_create_table_column(strid_get(pargs->si, yymsp[0].minor.yy33));
	free(yymsp[0].minor.yy33);
}
#line 1485 "sqlextract/parser.c"
        break;
      case 35: /* term ::= INTEGER|FLOAT|BLOB */
#line 319 "sqlextract/parser.ly"
{
	switch(yymsp[0].major) {
		case TK_INTEGER:
			yygotominor.yy67 = arbval_create_integer(atol(yymsp[0].minor.yy0));
			break;
		case TK_FLOAT:
			yygotominor.yy67 = arbval_create_real(atof(yymsp[0].minor.yy0));
			break;
		case TK_BLOB:
			yygotominor.yy67 = arbval_create_null();
			break;
	}
	free(yymsp[0].minor.yy0);
}
#line 1503 "sqlextract/parser.c"
        break;
      case 36: /* term ::= STRING */
#line 333 "sqlextract/parser.ly"
{
	char *str = strdup_unescape(yymsp[0].minor.yy0);
	yygotominor.yy67 = arbval_create_string(str);
	free(str);
	free(yymsp[0].minor.yy0);
}
#line 1513 "sqlextract/parser.c"
        break;
      case 37: /* expr ::= VARIABLE */
#line 339 "sqlextract/parser.ly"
{
  yy_destructor(yypParser,99,&yymsp[0].minor);
}
#line 1520 "sqlextract/parser.c"
        break;
      case 38: /* term ::= CTIME_KW */
#line 345 "sqlextract/parser.ly"
{
	yygotominor.yy67 = arbval_create_integer((long)time(NULL));
  yy_destructor(yypParser,56,&yymsp[0].minor);
}
#line 1528 "sqlextract/parser.c"
        break;
      case 39: /* expr ::= expr AND expr */
#line 349 "sqlextract/parser.ly"
{
	yygotominor.yy61 = filter_create_and(2, yymsp[-2].minor.yy61, yymsp[0].minor.yy61);
  yy_destructor(yypParser,60,&yymsp[-1].minor);
}
#line 1536 "sqlextract/parser.c"
        break;
      case 40: /* expr ::= expr OR expr */
#line 352 "sqlextract/parser.ly"
{
	yygotominor.yy61 = filter_create_or(2, yymsp[-2].minor.yy61, yymsp[0].minor.yy61);
  yy_destructor(yypParser,59,&yymsp[-1].minor);
}
#line 1544 "sqlextract/parser.c"
        break;
      case 41: /* expr ::= expr LT|GT|GE|LE expr */
#line 355 "sqlextract/parser.ly"
{
	switch(yymsp[-1].major) {
		case TK_LT: yygotominor.yy61 = filter_create_comp_lt(yymsp[-2].minor.yy61,yymsp[0].minor.yy61); break;
		case TK_GT: yygotominor.yy61 = filter_create_comp_gt(yymsp[-2].minor.yy61,yymsp[0].minor.yy61); break;
		case TK_GE: yygotominor.yy61 = filter_create_comp_ge(yymsp[-2].minor.yy61,yymsp[0].minor.yy61); break;
		case TK_LE: yygotominor.yy61 = filter_create_comp_le(yymsp[-2].minor.yy61,yymsp[0].minor.yy61); break;
		default:
			/* Some really strange error */
			yygotominor.yy61 = filter_create_and(0);
			filter_destroy(yymsp[-2].minor.yy61);
			filter_destroy(yymsp[0].minor.yy61);
	}
	free(yymsp[-1].minor.yy0);
}
#line 1562 "sqlextract/parser.c"
        break;
      case 42: /* expr ::= expr EQ|NE expr */
#line 369 "sqlextract/parser.ly"
{
	yygotominor.yy61 = filter_create_comp_eq(yymsp[-2].minor.yy61,yymsp[0].minor.yy61);
	if(yymsp[-1].major == TK_NE) {
		yygotominor.yy61 = filter_create_not(yygotominor.yy61);
	}
	free(yymsp[-1].minor.yy0);
}
#line 1573 "sqlextract/parser.c"
        break;
      case 44: /* expr ::= expr PLUS expr */
#line 378 "sqlextract/parser.ly"
{
	yygotominor.yy61 = filter_create_add(yymsp[-2].minor.yy61,yymsp[0].minor.yy61);
  yy_destructor(yypParser,78,&yymsp[-1].minor);
}
#line 1581 "sqlextract/parser.c"
        break;
      case 45: /* expr ::= expr MINUS expr */
#line 381 "sqlextract/parser.ly"
{
	yygotominor.yy61 = filter_create_sub(yymsp[-2].minor.yy61,yymsp[0].minor.yy61);
  yy_destructor(yypParser,79,&yymsp[-1].minor);
}
#line 1589 "sqlextract/parser.c"
        break;
      case 46: /* expr ::= expr STAR|SLASH|REM expr */
#line 385 "sqlextract/parser.ly"
{
	yygotominor.yy61 = NULL;
	switch(yymsp[-1].major) {
		case TK_STAR:  yygotominor.yy61 = filter_create_mul(yymsp[-2].minor.yy61, yymsp[0].minor.yy61); break;
		case TK_SLASH: yygotominor.yy61 = filter_create_div(yymsp[-2].minor.yy61, yymsp[0].minor.yy61); break;
		case TK_REM:   yygotominor.yy61 = filter_create_mod(yymsp[-2].minor.yy61, yymsp[0].minor.yy61); break;
	}
	free(yymsp[-1].minor.yy0);
}
#line 1602 "sqlextract/parser.c"
        break;
      case 47: /* expr ::= expr CONCAT expr */
#line 394 "sqlextract/parser.ly"
{
	yygotominor.yy61 = filter_create_concat(yymsp[-2].minor.yy61, yymsp[0].minor.yy61);
  yy_destructor(yypParser,83,&yymsp[-1].minor);
}
#line 1610 "sqlextract/parser.c"
        break;
      case 48: /* regexpop ::= REGEXP */
#line 400 "sqlextract/parser.ly"
{
	yygotominor.yy72 = FILTER_STRINGS_CASE_INSENSITIVE;
	free(yymsp[0].minor.yy0);
}
#line 1618 "sqlextract/parser.c"
        break;
      case 49: /* regexpop ::= NOT REGEXP */
#line 404 "sqlextract/parser.ly"
{
	yygotominor.yy72 = FILTER_STRINGS_CASE_INSENSITIVE | FILTER_STRINGS_INVERSE;
	free(yymsp[0].minor.yy0);
  yy_destructor(yypParser,61,&yymsp[-1].minor);
}
#line 1627 "sqlextract/parser.c"
        break;
      case 50: /* regexpop ::= REGEXP BINARY */
#line 410 "sqlextract/parser.ly"
{
	yygotominor.yy72 = FILTER_STRINGS_NONE;
	free(yymsp[-1].minor.yy0);
  yy_destructor(yypParser,100,&yymsp[0].minor);
}
#line 1636 "sqlextract/parser.c"
        break;
      case 51: /* regexpop ::= NOT REGEXP BINARY */
#line 416 "sqlextract/parser.ly"
{
	yygotominor.yy72 = FILTER_STRINGS_INVERSE;
	free(yymsp[-1].minor.yy0);
  yy_destructor(yypParser,61,&yymsp[-2].minor);
  yy_destructor(yypParser,100,&yymsp[0].minor);
}
#line 1646 "sqlextract/parser.c"
        break;
      case 52: /* expr ::= expr regexpop expr */
#line 421 "sqlextract/parser.ly"
{
	yygotominor.yy61 = filter_create_regexp(&(pargs->error), yymsp[-2].minor.yy61, yymsp[0].minor.yy61, yymsp[-1].minor.yy72);
}
#line 1653 "sqlextract/parser.c"
        break;
      case 53: /* likeop ::= LIKE_KW|MATCH */
#line 428 "sqlextract/parser.ly"
{
	yygotominor.yy72 = 0;
	free(yymsp[0].minor.yy0);
}
#line 1661 "sqlextract/parser.c"
        break;
      case 54: /* likeop ::= NOT LIKE_KW|MATCH */
#line 432 "sqlextract/parser.ly"
{
	yygotominor.yy72 = 1;
	free(yymsp[0].minor.yy0);
  yy_destructor(yypParser,61,&yymsp[-1].minor);
}
#line 1670 "sqlextract/parser.c"
        break;
      case 55: /* expr ::= expr likeop expr */
#line 437 "sqlextract/parser.ly"
{
	yygotominor.yy61 = filter_create_like(&(pargs->error), yymsp[-2].minor.yy61, yymsp[0].minor.yy61, NULL);
	if(yymsp[-1].minor.yy72) {
		yygotominor.yy61 = filter_create_not(yygotominor.yy61);
	}
}
#line 1680 "sqlextract/parser.c"
        break;
      case 56: /* expr ::= expr likeop expr ESCAPE expr */
#line 443 "sqlextract/parser.ly"
{
	yygotominor.yy61 = filter_create_like(&(pargs->error), yymsp[-4].minor.yy61, yymsp[-2].minor.yy61, yymsp[0].minor.yy61);
	if(yymsp[-3].minor.yy72) {
		yygotominor.yy61 = filter_create_not(yygotominor.yy61);
	}
  yy_destructor(yypParser,73,&yymsp[-1].minor);
}
#line 1691 "sqlextract/parser.c"
        break;
      case 57: /* expr ::= expr ISNULL|NOTNULL */
#line 450 "sqlextract/parser.ly"
{
	struct arbval_t *null = arbval_create_null();
	
	yygotominor.yy61 = filter_create_comp_is(yymsp[-1].minor.yy61, filter_create_constant(null));
	
	if(yymsp[0].major == TK_NOTNULL) {
		yygotominor.yy61 = filter_create_not(yygotominor.yy61);
	}
	
	arbval_destroy(null);
	free(yymsp[0].minor.yy0);
}
#line 1707 "sqlextract/parser.c"
        break;
      case 58: /* expr ::= expr NOT NULL */
#line 462 "sqlextract/parser.ly"
{
	struct arbval_t *null = arbval_create_null();
	yygotominor.yy61 = filter_create_not(filter_create_comp_is(yymsp[-2].minor.yy61, filter_create_constant(null)));
	arbval_destroy(null);
  yy_destructor(yypParser,61,&yymsp[-1].minor);
  yy_destructor(yypParser,95,&yymsp[0].minor);
}
#line 1718 "sqlextract/parser.c"
        break;
      case 59: /* expr ::= expr IS expr */
#line 468 "sqlextract/parser.ly"
{
	yygotominor.yy61 = filter_create_comp_is(yymsp[-2].minor.yy61, yymsp[0].minor.yy61);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
}
#line 1726 "sqlextract/parser.c"
        break;
      case 60: /* expr ::= expr IS NOT expr */
#line 472 "sqlextract/parser.ly"
{
	yygotominor.yy61 = filter_create_not(filter_create_comp_is(yymsp[-3].minor.yy61, yymsp[0].minor.yy61));
  yy_destructor(yypParser,62,&yymsp[-2].minor);
  yy_destructor(yypParser,61,&yymsp[-1].minor);
}
#line 1735 "sqlextract/parser.c"
        break;
      case 61: /* expr ::= NOT expr */
#line 478 "sqlextract/parser.ly"
{
	yygotominor.yy61 = filter_create_not(yymsp[0].minor.yy61);
  yy_destructor(yypParser,61,&yymsp[-1].minor);
}
#line 1743 "sqlextract/parser.c"
        break;
      case 62: /* expr ::= BITNOT expr */
#line 481 "sqlextract/parser.ly"
{
	/*
	 * Should be the bit inverse value, which is actually -1-x, since integers are
	 * 2's complement values for negative values.
	 */
	struct arbval_t *negone = arbval_create_integer(-1);
	yygotominor.yy61 = filter_create_sub( filter_create_constant(negone), yymsp[0].minor.yy61 );
	arbval_destroy(negone);
  yy_destructor(yypParser,85,&yymsp[-1].minor);
}
#line 1757 "sqlextract/parser.c"
        break;
      case 63: /* expr ::= MINUS expr */
#line 490 "sqlextract/parser.ly"
{
	struct arbval_t *zero = arbval_create_integer(0);
	yygotominor.yy61 = filter_create_sub( filter_create_constant(zero), yymsp[0].minor.yy61 );
	arbval_destroy(zero);
  yy_destructor(yypParser,79,&yymsp[-1].minor);
}
#line 1767 "sqlextract/parser.c"
        break;
      case 64: /* expr ::= PLUS expr */
#line 495 "sqlextract/parser.ly"
{
	yygotominor.yy61 = yymsp[0].minor.yy61;
  yy_destructor(yypParser,78,&yymsp[-1].minor);
}
#line 1775 "sqlextract/parser.c"
        break;
      case 65: /* between_op ::= BETWEEN */
#line 502 "sqlextract/parser.ly"
{
	yygotominor.yy72 = 0;
  yy_destructor(yypParser,63,&yymsp[0].minor);
}
#line 1783 "sqlextract/parser.c"
        break;
      case 66: /* between_op ::= NOT BETWEEN */
#line 505 "sqlextract/parser.ly"
{
	yygotominor.yy72 = 1;
  yy_destructor(yypParser,61,&yymsp[-1].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
}
#line 1792 "sqlextract/parser.c"
        break;
      case 67: /* expr ::= expr between_op expr AND expr */
#line 508 "sqlextract/parser.ly"
{
	yygotominor.yy61 = filter_create_between(yymsp[-4].minor.yy61, yymsp[-2].minor.yy61, yymsp[0].minor.yy61);
	if(yymsp[-3].minor.yy72) {
		yygotominor.yy61 = filter_create_not(yygotominor.yy61);
	}
  yy_destructor(yypParser,60,&yymsp[-1].minor);
}
#line 1803 "sqlextract/parser.c"
        break;
      default:
      /* (6) distinct ::= */ yytestcase(yyruleno==6);
      /* (10) as ::= */ yytestcase(yyruleno==10);
      /* (13) stl_prefix ::= */ yytestcase(yyruleno==13);
      /* (15) dbnm ::= */ yytestcase(yyruleno==15);
      /* (16) on_opt ::= */ yytestcase(yyruleno==16);
      /* (17) indexed_opt ::= */ yytestcase(yyruleno==17);
      /* (18) using_opt ::= */ yytestcase(yyruleno==18);
      /* (19) orderby_opt ::= */ yytestcase(yyruleno==19);
      /* (20) groupby_opt ::= */ yytestcase(yyruleno==20);
      /* (21) having_opt ::= */ yytestcase(yyruleno==21);
      /* (26) with ::= */ yytestcase(yyruleno==26);
      /* (43) expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr */ yytestcase(yyruleno==43);
        break;
  };
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yypParser->yyidx -= yysize;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact < YYNSTATE ){
#ifdef NDEBUG
    /* If we are not debugging and the reduce action popped at least
    ** one element off the stack, then we can push the new element back
    ** onto the stack here, and skip the stack overflow test in yy_shift().
    ** That gives a significant speed improvement. */
    if( yysize ){
      yypParser->yyidx++;
      yymsp -= yysize-1;
      yymsp->stateno = (YYACTIONTYPE)yyact;
      yymsp->major = (YYCODETYPE)yygoto;
      yymsp->minor = yygotominor;
    }else
#endif
    {
      yy_shift(yypParser,yyact,yygoto,&yygotominor);
    }
  }else{
    assert( yyact == YYNSTATE + YYNRULE + 1 );
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  logfilterParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
#line 47 "sqlextract/parser.ly"

	pargs->error = ERR_PARSE_FAILURE;
#line 1866 "sqlextract/parser.c"
  logfilterParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  YYMINORTYPE yyminor            /* The minor type of the error token */
){
  logfilterParserARG_FETCH;
#define TOKEN (yyminor.yy0)
#line 50 "sqlextract/parser.ly"

	pargs->error = ERR_SYNTAX_ERROR;
#line 1884 "sqlextract/parser.c"
  logfilterParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  logfilterParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
#line 45 "sqlextract/parser.ly"

#line 1905 "sqlextract/parser.c"
  logfilterParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "logfilterParserAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void logfilterParser(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  logfilterParserTOKENTYPE yyminor       /* The value for the token */
  logfilterParserARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  int yyact;            /* The parser action. */
  int yyendofinput;     /* True if we are at the end of input */
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  /* (re)initialize the parser, if necessary */
  yypParser = (yyParser*)yyp;
  if( yypParser->yyidx<0 ){
#if YYSTACKDEPTH<=0
    if( yypParser->yystksz <=0 ){
      /*memset(&yyminorunion, 0, sizeof(yyminorunion));*/
      yyminorunion = yyzerominor;
      yyStackOverflow(yypParser, &yyminorunion);
      return;
    }
#endif
    yypParser->yyidx = 0;
    yypParser->yyerrcnt = -1;
    yypParser->yystack[0].stateno = 0;
    yypParser->yystack[0].major = 0;
  }
  yyminorunion.yy0 = yyminor;
  yyendofinput = (yymajor==0);
  logfilterParserARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput %s\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact<YYNSTATE ){
      assert( !yyendofinput );  /* Impossible to shift the $ token */
      yy_shift(yypParser,yyact,yymajor,&yyminorunion);
      yypParser->yyerrcnt--;
      yymajor = YYNOCODE;
    }else if( yyact < YYNSTATE + YYNRULE ){
      yy_reduce(yypParser,yyact-YYNSTATE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yymx = yypParser->yystack[yypParser->yyidx].major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor,&yyminorunion);
        yymajor = YYNOCODE;
      }else{
         while(
          yypParser->yyidx >= 0 &&
          yymx != YYERRORSYMBOL &&
          (yyact = yy_find_reduce_action(
                        yypParser->yystack[yypParser->yyidx].stateno,
                        YYERRORSYMBOL)) >= YYNSTATE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yyidx < 0 || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          YYMINORTYPE u2;
          u2.YYERRSYMDT = 0;
          yy_shift(yypParser,yyact,YYERRORSYMBOL,&u2);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor,yyminorunion);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yyidx>=0 );
  return;
}
